<?php
/** @file
 *
 * @note Copyright (C) 2007-2010 Thomas ZILLIOX
 * 
 * This file is part of ZPHOTOS EXPRESS.
 * 
 * ZPHOTOS EXPRESS is free script: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License.
 * 
 * ZPHOTOS EXPRESS is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with ZPHOTOS EXPRESS. If not, see <http://www.gnu.org/licenses/>.
 * 
 * You can contact the author by e-mail thomas@zilliox.me
 * 
 */

/** @class
 * @author Thomas ZILLIOX
 * @date 2007-2010
 * @version 2.0
 */
class Zphotos_Options {
		
	
	/**************************************************************************
				ATTRIBUTES						
	**************************************************************************/

	/** 
	 * Est-ce que le mode RewriteRule est activé. (Booléen)
	 * @private
	 * @see isRewriteRule()
	 */
	var $isRewriteRule = false;

	/** 
	 * Url vers l'implémentation de Zphotos. (chaîne de caractères)
	 * @private
	 * @see getZphotosUrl()
	 * @see setZphotosUrl()
	 */
	var $zphotosUrl = './';

	/** 
	 * Chemin vers le dossier racine contenant les photos. (chaîne de caractères)
	 * @private
	 * @see getPhotosRootPath()
	 * @see setPhotosRootPath()
	 */
	var $photosRootPath = './photos/';

	/** 
	 * Nom de l'album racine. (chaîne de caractères)
	 * @private
	 * @see getRootAlbumName()
	 * @see setRootAlbumName()
	 */
	var $rootAlbumName = '';

	/** 
	 * Chemin vers le dossier contenant les themes Zphotos. (chaîne de caractères)
	 * @private
	 * @see getThemesPath()
	 * @see setThemesPath()
	 */
	var $themesPath = './themes/';
	
	/** 
	 * Le nom de la variable indiquant la photo dans l'url. (chaîne de caractères)
	 * @private
	 * @see getPhotoVarName()
	 * @see setPhotoVarName()
	 */
	var $photoVarName = 'photo';

	/** 
	 * Le nom de la variable indiquant l'album dans l'url. (chaîne de caractères)
	 * @private
	 * @see getAlbumVarName()
	 * @see setAlbumVarName()
	 */
	var $albumVarName = 'album';

	/** 
	 * Le nom de la variable indiquant la page de l'album dans l'url. (chaîne de caractères)
	 * @private
	 * @see getPageVarName()
	 * @see setPageVarName()
	 */
	var $pageVarName = 'page';

	/** 
	 * Extension indiquant que l'url est une photo. (chaîne de caractères)
	 * @private
	 * @see getPhotoExtension()
	 * @see setPhotoExtension()
	 */
	var $photoExtension = '';

	/** 
	 * Extension indiquant que l'url est un album. (chaîne de caractères)
	 * @private
	 * @see getAlbumExtension()
	 * @see setAlbumExtension()
	 */
	var $albumExtension = '';

	/** 
	 * Extension indiquant que l'url est une page d'un album. (chaîne de caractères)
	 * @private
	 * @see getPageExtension()
	 * @see setPageExtension()
	 */
	var $pageExtension = '';

	/** 
	 * Est-ce que les descriptions des albums doivent être utilisé pour les photos si elles n'en n'ont pas. (booléen)
	 * @private
	 * @see isInheritedDescription()
	 * @see setIsInheritedDescription()
	 */
	var $isInheritedDescription = false;
	
	
	/**************************************************************************
				ACCESSORS						
	**************************************************************************/
	/** @name Accessors
	 */
	//@{

	/** 
	 * @public
	 * @return Url vers l'implémentation de Zphotos. (chaîne de caractères)
	 * @see setZphotosUrl()
	 */
	function getZphotosUrl() {
		return $this->zphotosUrl;
	}

	/** 
	 * @public
	 * @return Url vers le dossier racine de Zphotos. (chaîne de caractères)
	 * @see setZphotosUrl()
	 */
	function getZphotosFolderUrl() {
		if (substr($this->zphotosUrl, -1) == '/') return $this->zphotosUrl;
		return dirname($this->zphotosUrl).'/';
	}

	/** 
	 * @public
	 * @param $zphotosUrl, Url vers l'implémentation de Zphotos. (chaîne de caractères)
	 * @see getZphotosUrl()
	 */
	function setZphotosUrl($zphotosUrl) {
		$this->zphotosUrl = $zphotosUrl;
	}

	/**
	 * @public
	 * @return Chemin vers le dossier racine contenant les photos. (chaîne de caractères)
	 * @see setPhotosRootPath()
	 */
	function getPhotosRootPath() {
		return $this->photosRootPath;
	}

	/**
	 * @public
	 * @param $rootPath, Chemin vers le dossier racine contenant les photos. (chaîne de caractères)
	 * @see getPhotosRootPath()
	 */
	function setPhotosRootPath($photosRootPath) {
		$this->photosRootPath = $photosRootPath;
	}

	/** 
	 * @public
	 * @return le nom de l'album racine. (chaîne de caractères)
	 * @see setRootAlbumName()
	 */
	function getRootAlbumName() {
		return $this->rootAlbumName;
	}

	/** 
	 * @public
	 * @param $rootAlbumName, le nom de l'album racine. (chaîne de caractères)
	 * @see getRootAlbumName()
	 */
	function setRootAlbumName($rootAlbumName) {
		$this->rootAlbumName = $rootAlbumName;
	}

	/** 
	 * @public
	 * @return Chemin vers le dossier contenant les themes Zphotos. (chaîne de caractères)
	 * @see setThemesPath()
	 */
	function getThemesPath() {
		return $this->themesPath;
	}

	/** 
	 * @public
	 * @param $themesPath, Chemin vers le dossier contenant les themes Zphotos. (chaîne de caractères)
	 * @see getThemesPath()
	 */
	function setThemesPath($themesPath) {
		$this->themesPath = $themesPath;
	}

	/** 
	 * @public
	 * @return Est-ce que le mode RewriteRule est activé. (Booléen)
	 */
	function isRewriteRule() {
		return $this->isRewriteRule;
	}

	/** 
	 * @public
	 * @return Le nom de la variable indiquant la photo dans l'url. (chaîne de caractères)
	 * @see setPhotoVarName()
	 */
	function getPhotoVarName() {
		return $this->photoVarName;
	}

	/** 
	 * @public
	 * @param $photoVarName, Le nom de la variable indiquant la photo dans l'url. (chaîne de caractères)
	 * @see getPhotoVarName()
	 */
	function setPhotoVarName($photoVarName) {
		$this->photoVarName = $photoVarName;
	}

	/** 
	 * @public
	 * @return Le nom de la variable indiquant l'album dans l'url. (chaîne de caractères)
	 * @see setAlbumVarName()
	 */
	function getAlbumVarName() {
		return $this->albumVarName;
	}

	/** 
	 * @public
	 * @param $albumVarName, Le nom de la variable indiquant l'album dans l'url. (chaîne de caractères)
	 * @see getAlbumVarName()
	 */
	function setAlbumVarName($albumVarName) {
		$this->albumVarName = $albumVarName;
	}

	/** 
	 * @public
	 * @return Le nom de la variable indiquant la page de l'album dans l'url. (chaîne de caractères)
	 * @see setPageVarName()
	 */
	function getPageVarName() {
		return $this->pageVarName;
	}

	/** 
	 * @public
	 * @param $pageVarName, Le nom de la variable indiquant la page de l'album dans l'url. (chaîne de caractères)
	 * @see getPageVarName()
	 */
	function setPageVarName($pageVarName) {
		$this->pageVarName = $pageVarName;
	}

	/** 
	 * @public
	 * @return Extension indiquant que l'url est une photo. (chaîne de caractères)
	 * @see setPhotoExtension()
	 */
	function getPhotoExtension() {
		return $this->photoExtension;
	}

	/** 
	 * @public
	 * @param $photoExtension, Extension indiquant que l'url est une photo. (chaîne de caractères)
	 * @see getPhotoExtension()
	 */
	function setPhotoExtension($photoExtension) {
		$this->photoExtension = $photoExtension;
	}

	/** 
	 * @public
	 * @return Extension indiquant que l'url est un album. (chaîne de caractères)
	 * @see setAlbumExtension()
	 */
	function getAlbumExtension() {
		return $this->albumExtension;
	}

	/** 
	 * @public
	 * @param $albumExtension, Extension indiquant que l'url est un album. (chaîne de caractères)
	 * @see getAlbumExtension()
	 */
	function setAlbumExtension($albumExtension) {
		$this->albumExtension = $albumExtension;
	}

	/** 
	 * @public
	 * @return Extension indiquant que l'url est une page d'un album. (chaîne de caractères)
	 * @see setPageExtension()
	 */
	function getPageExtension() {
		return $this->pageExtension;
	}

	/** 
	 * @public
	 * @param $pageExtension, Extension indiquant que l'url est une page d'un album. (chaîne de caractères)
	 * @see getPageExtension()
	 */
	function setPageExtension($pageExtension) {
		$this->pageExtension = $pageExtension;
	}

	/** 
	 * @public
	 * @return Est-ce que les descriptions des albums doivent être utilisé pour les photos si elles n'en n'ont pas. (booléen)
	 * @see setIsInheritedDescription()
	 */
	function isInheritedDescription() {
		return $this->isInheritedDescription;
	}

	/** 
	 * @public
	 * @param $isInheritedDescription, Est-ce que les descriptions des albums doivent être utilisé pour les photos si elles n'en n'ont pas. (booléen)
	 * @see isInheritedDescription()
	 */
	function setIsInheritedDescription($isInheritedDescription) {
		$this->isInheritedDescription = $isInheritedDescription;
	}
	//@}
	
	
	/**************************************************************************
				CONSTRUCTOR							
	**************************************************************************/
	/** @name Constructor
	 */
	//@{

	/** 
	 * Constructeur PHP4.
	 * @private (for the visibility in the documentation)
	 * @param $isRewriteRule, Est-ce que le mode RewriteRule est activé. (Booléen)
	 * @see __construct()
	 */
	function Zphotos_Options($isRewriteRule) {
		$this->__construct($isRewriteRule);
	}

	/** 
	 * Constructeur.
	 * @public
	 * @param $isRewriteRule, Est-ce que le mode RewriteRule est activé. (Booléen)
	 */
	function __construct() {
		if (func_num_args() > 0) $isRewriteRule = func_get_arg(0);
		else $isRewriteRule = false;
		if ($isRewriteRule) {
			$this->isRewriteRule = true;
			$this->zphotosUrl = '/';
			$this->photoExtension = '.zoom';
			$this->pageExtension = '.page';
		}
	}
	//@}
}
?>