<?php
/** @file
 *
 * @note Copyright (C) 2007-2010 Thomas ZILLIOX
 * 
 * This file is part of ZPHOTOS EXPRESS.
 * 
 * ZPHOTOS EXPRESS is free script: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License.
 * 
 * ZPHOTOS EXPRESS is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with ZPHOTOS EXPRESS. If not, see <http://www.gnu.org/licenses/>.
 * 
 * You can contact the author by e-mail thomas@zilliox.me
 * 
 */

/** @class
 * @author Thomas ZILLIOX
 * @date 2007-2010
 * @version 2.0
 */
class Zphotos_Photo extends Zphotos_Data {
	
	
	/**************************************************************************
				ATTRIBUTES						
	/*************************************************************************/

	/** 
	 * Largeur de la photo. (nombre)
	 * @private
	 */
	var $width;

	/** 
	 * Hauteur de la photo. (nombre)
	 * @private
	 */
	var $height;
	
	
	/**************************************************************************
				PUBLIC ACCESSORS						
	**************************************************************************/
	/** @name Accessors
	 */
	//@{

	/** 
	 * @public
	 * @return la largeur de la photo en pixel. (nombre)
	 */
	function getWidth(){
		if ($this->width == null) $this->_initImageSize();
		return $this->width;
	}

	/** 
	 * @public
	 * @return la hauteur de la photo en pixel. (nombre)
	 */
	function getHeight(){
		if ($this->width == null) $this->_initImageSize();
		return $this->height;
	}
	

	//@}
	/**************************************************************************
				PUBLIC METHODS					
	**************************************************************************/
	
	/** 
	 * @public
	 * @note cette url peut être utilisée pour l'attribut src des balises <img>.
	 * @return l'url de la photo. (chaîne de caractères)
	 */
	function getUrl() {
		return $this->options->getZphotosFolderUrl().$this->options->getPhotosRootPath().zp_rawurlencode($this->relativePath);
	}
	
	/** 
	 * @public
	 * @note cette url peut être utilisée pour les liens sur les miniatures.
	 * @return l'url de la page de zoom de la photo. (chaîne de caractères)
	 */
	function getZoomUrl(){
		if ($this->options->isRewriteRule()) {
			return $this->album->getBaseUrl().$this->name.$this->options->getPhotoExtension();
		} else {
			return $this->album->getBaseUrl().'&'.$this->options->getPhotoVarName().'='.$this->name.$this->options->getPhotoExtension();
		}
	}
	// @}
	
	
	/**************************************************************************
				CONSTRUCTOR							
	**************************************************************************/

	/** 
	 * Constructeur PHP4.
	 * @private (for the visibility in the documentation)
	 * @param le chemin de la photo. (chaîne de caractères)
	 * @param l'album d'où provient la photo. (objet Zphotos_Album)
	 * @param les options de Zphotos Express. (objet Zphotos_Options)
	 * @see __construct()
	 */
	function Zphotos_Photo($path, &$album, &$options) {
		$this->__construct($path, $album, $options);
	}

	/** 
	 * Constructeur.
	 * @public
	 * @param le chemin de la photo. (chaîne de caractères)
	 * @param l'album d'où provient la photo. (objet Zphotos_Album)
	 * @param les options de Zphotos Express. (objet Zphotos_Options)
	 */
	function __construct($path, &$album, &$options) {
		parent::__construct($path, $album, $options);
		if ($options->isInheritedDescription() && $this->description == '') {
			$this->description = $album->getDescriptionHTML();
		}
	}
	
	
	/**************************************************************************
				PRIVATE METHODS						
	**************************************************************************/

	/** 
	 * Récupère la largeur et la hauteur de l'image et l'enregistre en attribut.
	 * @private
	 */
	function _initImageSize(){
		$size = getimagesize($this->getPath());
		$this->width = $size[0];
		$this->height = $size[1];
	}
}
?>