<?php
/** @file
 *
 * @note Copyright (C) 2007-2010 Thomas ZILLIOX
 * 
 * This file is part of ZPHOTOS EXPRESS.
 * 
 * ZPHOTOS EXPRESS is free script: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License.
 * 
 * ZPHOTOS EXPRESS is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with ZPHOTOS EXPRESS. If not, see <http://www.gnu.org/licenses/>.
 * 
 * You can contact the author by e-mail thomas@zilliox.me
 * 
 */

/**************************************************************************
			UTILS								
**************************************************************************/
/** @name Utils
 */
//@{

/** 
 * @public
 * @param texte de référence. (chaîne de caractères)
 * @param texte recherché. (chaîne de caractères)
 * @return true si le texte de référence commence par le texte recherché en tenant compte de la casse. (booléen)
 * @see zp_istartswith()
 * @see zp_endswith()
 */
function zp_startswith($hay, $needle) {
  return substr($hay, 0, strlen($needle)) == $needle;
}

/** 
 * @public
 * @param texte de référence. (chaîne de caractères)
 * @param texte recherché. (chaîne de caractères)
 * @return true si le texte de référence fini par le texte recherché en tenant compte de la casse. (booléen)
 * @see zp_startswith()
 * @see zp_iendswith()
 */
function zp_endswith($hay, $needle) {
  return substr($hay, -strlen($needle)) == $needle;
}

/** 
 * @public
 * @param texte de référence. (chaîne de caractères)
 * @param texte recherché. (chaîne de caractères)
 * @return true si le texte de référence commence par le texte recherché sans tenir compte de la casse. (booléen)
 * @see zp_startswith()
 * @see zp_iendswith()
 */
function zp_istartswith($hay, $needle) {
  return zp_startswith(strtolower($hay), strtolower($needle));
}

/** 
 * @public
 * @param texte de référence. (chaîne de caractères)
 * @param texte recherché. (chaîne de caractères)
 * @return true si le texte de référence fini par le texte recherché sans tenir compte de la casse. (booléen)
 * @see zp_istartswith()
 * @see zp_endswith()
 */
function zp_iendswith($hay, $needle) {
  return zp_endswith(strtolower($hay), strtolower($needle));
}

/** 
 * @public
 * Permet d'ouvrir un message d'alerte javascript contenant la variable que l'on souhaite afficher
 * @param variable à afficher.
 */
function zp_alert($var) {
	if (is_bool($var)) {
		if ($var) $text = 'true';
		else $text = 'false';
	} else $text = $var;
	echo '<script type="text/javascript">alert("'.$text.'");</script>';
}

/** 
 * @public
 * @param texte à encodre. (chaîne de caractères)
 * @return encode le texte avec la méthode rawurlencode() et encode en plus les caratères '/'. (chaîne de caractères)
 */
function zp_rawurlencode($str) {
	return str_replace('%2F', '/', rawurlencode($str));
}
//@}