<?php
/** @file
 *
 * @note Copyright (C) 2007-2010 Thomas ZILLIOX
 * 
 * This file is part of ZPHOTOS EXPRESS.
 * 
 * ZPHOTOS EXPRESS is free script: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License.
 * 
 * ZPHOTOS EXPRESS is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with ZPHOTOS EXPRESS. If not, see <http://www.gnu.org/licenses/>.
 * 
 * You can contact the author by e-mail thomas@zilliox.me
 * 
 */

/** @class
 * @author Thomas ZILLIOX
 * @date 2007-2010
 * @version 2.0
 */
class Zen_Journey_View extends Zphotos_View {
		
	
	/**************************************************************************
				PUBLIC METHODS						
	**************************************************************************/

	/** 
	 * @public
	 * @param $album, L'album à afficher.
	 * @param $page, La page de l'album à afficher.
	 * @return Le code HTML de la page représentant l'album passé en paramètre.
	 */
	function showAlbum($album, $page) {
		// Title
		$title = ucfirst($album->getName());
		
		// Url
		$rootUrl = $album->options->getZphotosFolderUrl();
		
		// Menu
		$menu = '<div class="back">';
		if ($album->hasAlbum()) {
			$parent = $album->getAlbum();
			$menu .= '<a href="'.$parent->getUrl().'"><< Album parent</a>';
		}
		$menu .= '</div>
			<h2>'.ucfirst($album->getName()).'</h2>
			<p class="first">'.$album->getDescription().'</p>';
		
		// Head
		$head = '';
		if ($album->getAlbumsNumber() == 0 && $album->getPhotosNumber() == 0) {
			$head = 'Cet album est vide.';
		} else {
			if ($album->getAlbumsNumber() != 0) $head = $album->getAlbumsNumber().' sous-albums ';
			if ($album->getAlbumsNumber() != 0 && $album->getPhotosNumber() != 0) $head .= 'et ';
			if ($album->getPhotosNumber() != 0) $head .= $album->getPhotosNumber().' photos ';
		}
		
		// Content
		$content = $this->_getAlbumsHTML($album).$this->_getPhotosHTML($album, 0, 'diapo', true, 'crop', 120, 90);
		
		// Return
		return $this->_useTemplate($title, $rootUrl, $menu, $head, $content);
	}

	/** 
	 * @public
	 * @param $photo, La photo à afficher
	 * @return Le code HTML de la page représentant la photo passée en paramètre.
	 */
	function showPhoto($photo) {
		// Title
		$album = $photo->getAlbum();
		$title = ucfirst($photo->getName()).' - '.ucfirst($album->getName());
		
		// Url
		$rootUrl = $photo->options->getZphotosFolderUrl();
		
		// Menu
		$album = $photo->getAlbum();
		$menu = '<div class="back"><a href="'.$album->getUrl().'"><< Album</a></div>
					<h2>'.ucfirst($photo->getName()).'</h2>
					<p class="first">'.$photo->getDescription().'</p>';
		
		// Head
		$head = '';
		if ($album->hasPreviousPhoto($photo)) {
			$previous = $album->getPreviousPhoto($photo);
			$head = '<a class="previous" href="'.$previous->getZoomUrl().'"><< Photo précédente</a>';
		}
		if ($album->hasNextPhoto($photo)) {
			$next = $album->getNextPhoto($photo);
			$head .= '<a class="next" href="'.$next->getZoomUrl().'">Photo suivante >></a>';
		}
		
		// Content
		$content = '<div class="zoom">'.$this->_getPhotoHTML($photo, '', false, 'resize', 470, 400).'</div>';
		
		// Return
		return $this->_useTemplate($title, $rootUrl, $menu, $head, $content);
	}
	
	
	/**************************************************************************
				PRIVATE PHOTO METHODS						
	**************************************************************************/

	/** 
	 * @private
	 * @param $replace, valeurs de remplacement dans la template
	 * @return Le code HTML de la page représentant la photo passée en paramètre.
	 */
	function _useTemplate($title, $rootUrl, $menu, $head, $content) {
		$template = "";
		$search = array(
			'__TITLE__',
			'__ROOT_URL__',
			'__MENU__',
			'__HEAD__',
			'__CONTENT__',
			'__CREDITS__');
		$replace = array(
			$title,
			$rootUrl,
			$menu,
			$head,
			$content,
			$this->credits);
		$file = dirname(__FILE__). '/template.html';
		if (file_exists($file)) {
			$template = file_get_contents($file);
		} else {
			echo 'Error, template not found : '.$file.' !';
		}
		return str_replace($search, $replace, $template);
	}
}
?>